==> 0.0.0.zip: blokkify-lang/js/loader.js <==
function FileLoader(sprite) {
    this.elem = document.querySelector('input[type=file]');
    this.sprite = sprite;
    this.change();
    this.type = "project";
}

FileLoader.prototype.download = function () {
    let codes = { __origin: thing2 ? thing2.split('/projects/')[1] : '' };
    for (let i in this.sprite.sprites) {
        if (this.sprite.sprites[i].isClone) continue;
        codes[i] = {};
        codes[i].code = this.sprite.sprites[i].code;
    }
    var dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(codes));
    var dlAnchorElem = document.createElement('a');
    dlAnchorElem.setAttribute("href", dataStr);
    dlAnchorElem.setAttribute("download", "project.json");
    dlAnchorElem.click();
}

FileLoader.prototype.change = function () {
    let that = this;
    this.elem.onchange = async function (e) {

        let formData = new FormData();
        let f = e.target.files[0];

        if (that.type == 'project') {
            let reader = new FileReader();
            reader.onload = function (evt) {
                loaderFunc(JSON.parse(evt.target.result))
            }
            reader.readAsText(f, "UTF-8");
            return;
        }

        formData.append('file', f);
        formData.append('tokenIn', tokenIn);

        let dat = await fetch('https://api.blokkify.net/upload/asset', {
            body: formData,
            method: "POST"
        });
        let datJson = await dat.json();
        let {filesR} = datJson;

        let str = `(set (text (costume)) (image (text (https://api.blokkify.net/raw?sub=assets&id=${filesR}))))`;
        if (f.name.endsWith('mp3')) {
            str = `(play (audio (text (https://api.blokkify.net/raw?sub=assets&id=${filesR}))))`;
        }

        document.querySelector('.left').value = document.querySelector('.left').value + str;
        view.blocks();
        return;
    }
}

FileLoader.prototype.upload = function () {
    this.type = "project";
    document.querySelector('input[type=file]').click();
}

FileLoader.prototype.uploadAsset = function () {
    this.type = "asset";
    document.querySelector('input[type=file]').click();
}

==> 0.1.0.zip: blokkify-lang/js/loader.js <==
function FileLoader(sprite) {
    this.elem = document.querySelector('input[type=file]');
    this.sprite = sprite;
    this.change();
    this.type = "project";
}

FileLoader.prototype.download = function (isData) {
    let codes = { __origin: thing2 ? thing2.split('/projects/')[1] : '' };
    for (let i in this.sprite.sprites) {
        if (this.sprite.sprites[i].isClone) continue;
        codes[i] = {};
        codes[i].code = this.sprite.sprites[i].code;
    }
    if (isData) return codes;
    var dataStr = "data:text/json;charset=utf-8," + encodeURIComponent(JSON.stringify(codes));
    var dlAnchorElem = document.createElement('a');
    dlAnchorElem.setAttribute("href", dataStr);
    dlAnchorElem.setAttribute("download", "project.json");
    dlAnchorElem.click();
}

FileLoader.prototype.change = function () {
    let that = this;
    this.elem.onchange = async function (e) {

        let formData = new FormData();
        let f = e.target.files[0];

        if (that.type == 'project') {
            let reader = new FileReader();
            reader.onload = function (evt) {
                loaderFunc(JSON.parse(evt.target.result))
            }
            reader.readAsText(f, "UTF-8");
            return;
        }

        formData.append('file', f);
        formData.append('tokenIn', tokenIn);

        let dat = await fetch('https://api.blokkify.net/upload/asset', {
            body: formData,
            method: "POST"
        });
        let datJson = await dat.json();
        let {filesR} = datJson;

        let str = `(set (text (costume)) (image (text (https://api.blokkify.net/raw?sub=assets&id=${filesR}))))`;
        if (f.name.endsWith('mp3')) {
            str = `(play (audio (text (https://api.blokkify.net/raw?sub=assets&id=${filesR}))))`;
        }

        document.querySelector('.left').value = document.querySelector('.left').value + str;
        view.blocks();
        return;
    }
}

FileLoader.prototype.upload = function () {
    this.type = "project";
    document.querySelector('input[type=file]').click();
}

FileLoader.prototype.uploadAsset = function () {
    this.type = "asset";
    document.querySelector('input[type=file]').click();
}

FileLoader.prototype.toStorage = function() {
    let pop = window.open('https://blokkify.net/upload#section_project','_blank');
    let that = this;
    setTimeout(function() {
        pop.postMessage(that.download(true), 'https://blokkify.net');
    },1000);
}
